dopes.equipment_control.mecom.exceptions API documentation
Description: This file contains some custom expceptions.

# Module `dopes.equipment_control.mecom.exceptions`

This file contains some custom expceptions.

## Classes

`class ResponseException (*args, **kwargs)`
  Expand source code

      class ResponseException(Exception):
          pass

  Common base class for all non-exit exceptions.

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException

  ### Subclasses

  - ResponseTimeout
  - WrongResponseSequence
`class ResponseTimeout (*args, **kwargs)`
  Expand source code

      class ResponseTimeout(ResponseException):
          pass

  Common base class for all non-exit exceptions.

  ### Ancestors

  - ResponseException
  - builtins.Exception
  - builtins.BaseException
`class UnknownMeComType (*args, **kwargs)`
  Expand source code

      class UnknownMeComType(Exception):
          pass

  Common base class for all non-exit exceptions.

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class UnknownParameter (*args, **kwargs)`
  Expand source code

      class UnknownParameter(Exception):
          pass

  Common base class for all non-exit exceptions.

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class WrongChecksum (*args, **kwargs)`
  Expand source code

      class WrongChecksum(Exception):
          pass

  Common base class for all non-exit exceptions.

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class WrongResponseSequence (*args, **kwargs)`
  Expand source code

      class WrongResponseSequence(ResponseException):
          pass

  Common base class for all non-exit exceptions.

  ### Ancestors

  - ResponseException
  - builtins.Exception
  - builtins.BaseException